@@ -4,19 +4,19 @@
 #   Copyright (C) 2014  Enno Rodegerdts
 #   Copyright (C) 2022  Andrew Bauer
 
-#  This program is free software; you can redistribute it and/or modify
-#     it under the terms of the GNU General Public License as published by
-#     the Free Software Foundation; either version 2 of the License, or
-#     (at your option) any later version.
-# 
-#     This program is distributed in the hope that it will be useful,
-#     but WITHOUT ANY WARRANTY; without even the implied warranty of
-#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU General Public License for more details.
-# 
-#     You should have received a copy of the GNU General Public License along
-#     with this program; if not, write to the Free Software Foundation, Inc.,
-#     51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+#   This program is free software; you can redistribute it and/or modify
+#   it under the terms of the GNU General Public License as published by
+#   the Free Software Foundation; either version 2 of the License, or
+#   (at your option) any later version.
+#
+#   This program is distributed in the hope that it will be useful,
+#   but WITHOUT ANY WARRANTY; without even the implied warranty of
+#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#   GNU General Public License for more details.
+#
+#   You should have received a copy of the GNU General Public License along
+#   with this program; if not, write to the Free Software Foundation, Inc.,
+#   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # NOTE: the new format statement requires a literal '{' to be entered as '{{',
 #       and a literal '}' to be entered as '}}'. The old '%' format specifier
@@ -247,9 +247,9 @@ def planetstab(dfloat):
         tab = tab + r'''\hline
 \multicolumn{{2}}{{|c|}}{{\rule{{0pt}}{{2.4ex}}Mer.pass. {}}} & 
 \multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}\hphantom{{0}}}} & 
-\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}}} & 
 \multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}\hphantom{{0}}}} & 
-\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}}}\\
+\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}\hphantom{{0}}}} & 
+\multicolumn{{2}}{{c|}}{{\(\nu\) {}$'$ \emph{{d}} {}$'$ m {}\hphantom{{0}}}}\\
 \hline
 \multicolumn{{10}}{{c}}{{}}\\
 '''.format(alma_ephem.ariestransit(dfloat + n),vd[0],vd[1],vd[2],vd[3],vd[4],vd[5],vd[6],vd[7],vd[8],vd[9],vd[10],vd[11])
@@ -349,9 +349,9 @@ def planetstabm(dfloat):
         tab = tab + r'''\cmidrule{{1-2}} \cmidrule{{4-5}} \cmidrule{{7-8}} \cmidrule{{10-11}} \cmidrule{{13-14}}
 \multicolumn{{2}}{{c}}{{\footnotesize{{Mer.pass. {}}}}} && 
 \multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}\hphantom{{0}}}}}} && 
-\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}}}}} && 
 \multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}\hphantom{{0}}}}}} && 
-\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}}}}}\\
+\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}\hphantom{{0}}}}}} && 
+\multicolumn{{2}}{{c}}{{\footnotesize{{\(\nu\){}$'$ \emph{{d}}{}$'$ m{}\hphantom{{0}}}}}}\\
 \cmidrule{{1-2}} \cmidrule{{4-5}} \cmidrule{{7-8}} \cmidrule{{10-11}} \cmidrule{{13-14}}
 '''.format(alma_ephem.ariestransit(dfloat + n),vd[0],vd[1],vd[2],vd[3],vd[4],vd[5],vd[6],vd[7],vd[8],vd[9],vd[10],vd[11])
         # the phantom character '0' compensates the format with two decimal places in SFalmanac
@@ -373,7 +373,8 @@ def starstab(dfloat):
     # OLD: \begin{tabular*}{0.25\textwidth}[t]{@{\extracolsep{\fill}}|rrr|}
 
     if config.tbls == "m":
-        out = r'''\setlength{\tabcolsep}{4pt}  % default 6pt
+        out = r'''\renewcommand{\arraystretch}{1.1}
+\setlength{\tabcolsep}{4pt}  % default 6pt
 \begin{tabular}[t]{|rrr|}
 \multicolumn{3}{c}{\normalsize{Stars}}\\
 \hline
@@ -646,7 +647,8 @@ def twilighttab(dfloat):
     if config.tbls == "m":
     # The header begins with a thin empty row as top padding; and the top row with
     # bold text has some padding below it. This result gives a balanced impression.
-        tab = r'''\setlength{\tabcolsep}{5pt}  % default 6pt
+        tab = r'''\renewcommand{\arraystretch}{1.05}
+\setlength{\tabcolsep}{5pt}  % default 6pt
 \begin{tabular}[t]{|r|ccc|ccc|}
 \multicolumn{7}{c}{\normalsize{}}\\
 \hline
@@ -916,7 +918,7 @@ def doublepage(first_day, page1):
 \textbf{{{} to {}}}{}%
 \end{{flushright}}\par
 \begin{{scriptsize}}
-'''.format(tm, bm, oddim, oddom, ephem.date(dfloat).datetime().strftime("%Y %B %d"), ephem.date(dfloat+2).datetime().strftime("%b. %d"), rightindent)
+'''.format(oddtm, bm, oddim, oddom, ephem.date(dfloat).datetime().strftime("%Y %B %d"), ephem.date(dfloat+2).datetime().strftime("%b. %d"), rightindent)
 # >>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
 
     page = page + str1
@@ -1054,6 +1056,8 @@ def makeNAnew(first_day, dtp, dfA4):
     global oddtm,  oddbm,  oddim,  oddom,  oddhs,  oddfs  # required by doublepage
     global eventm, evenbm, evenim, evenom, evenhs, evenfs
 
+    # NOTE: 'bm' (bottom margin) is an unrealistic value used only to determine the vertical size of 'body' (textheight), which must be large enough to include all the tables. 'tm' (top margin) and 'hds' (headsep) determine the top of body. Note: 'fs' (footskip) does not position the footer.
+
     # page size specific parameters
     if config.pgsz == "A4":
         # A4 ... pay attention to the limited page width
@@ -1126,10 +1130,10 @@ def makeNAnew(first_day, dtp, dfA4):
             evenfs = "12pt"     # footskip (page 2 onwards)
             evenim = "12.5mm"
             evenom = "12.5mm"
-            # odd data pages...
-            oddtm = "11mm"      # was "4mm"
+            # odd data pages... use 26.06.2024 as a testcase
+            oddtm = "8mm"       # was "4mm"
             oddbm = "8mm"       # was "8mm"
-            oddhs = "2.5pt"     # headsep  (page 3 onwards)
+            oddhs = "0pt"       # headsep  (page 3 onwards)
             oddfs = "12pt"      # footskip (page 3 onwards)
             oddim = "13mm"
             oddom = "13mm"
@@ -1280,11 +1284,11 @@ def hdrNAold(first_day, dtp, tm1, bm1, lm1, rm1, vsep1, vsep2, dfA4):
 
 def makeNAold(first_day, dtp, dfA4):
     # make almanac starting from first_day
-    global tm, bm, oddim, oddom     # required by doublepage
+    global tm, bm, oddtm, oddim, oddom     # required by doublepage
 
     # page size specific parameters
     if config.pgsz == "A4":
-        # pay attention to the limited page width
+        # A4 ... pay attention to the limited page width
         paper = "a4paper"
         vsep1 = "2.0cm"
         vsep2 = "1.5cm"
@@ -1298,6 +1302,7 @@ def makeNAold(first_day, dtp, dfA4):
         im = "10mm"     # inner margin (right side on even pages)
         om = "9mm"      # outer margin (left side on even pages)
         # odd data pages...
+        oddtm = tm
         oddim = "14mm"  # inner margin (left side on odd pages)
         oddom = "11mm"  # outer margin (right side on odd pages)
         if config.tbls == "m":
@@ -1307,10 +1312,11 @@ def makeNAold(first_day, dtp, dfA4):
             im = "10mm"
             om = "10mm"
             # odd data pages...
+            oddtm = tm
             oddim = "14mm"
             oddom = "11mm"
     else:
-        # pay attention to the limited page height
+        # LETTER ... pay attention to the limited page height
         paper = "letterpaper"
         vsep1 = "1.5cm"
         vsep2 = "1.0cm"
@@ -1324,6 +1330,7 @@ def makeNAold(first_day, dtp, dfA4):
         im = "13mm"     # inner margin (right side on even pages)
         om = "13mm"     # outer margin (left side on even pages)
         # odd data pages...
+        oddtm = tm
         oddim = "14mm"  # inner margin (left side on odd pages)
         oddom = "11mm"  # outer margin (right side on odd pages)
         if config.tbls == "m":
@@ -1332,7 +1339,8 @@ def makeNAold(first_day, dtp, dfA4):
             bm = "8mm"
             im = "12mm"
             om = "12mm"
-            # odd data pages...
+            # odd data pages... use 26.06.2024 & 18.06.2025 as testcases
+            oddtm = "2.6mm"
             oddim = "14mm"
             oddom = "14mm"
 
